ge

Function ge 

pub fn ge(a: &[u64], b: &[u64]) -> bool
Compare two limb slices in reverse order, returns true if a >= b.

Assumes that if the slices are of different length, the longer slice is always greater than the shorter slice.